<?php

namespace Eform\Business\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Eform\Business\Http\Requests\BusinessActionsRequest;
use Eform\Business\Actions\BusinessActions;

/**
 * Admin web controller class.
 */
class BusinessActionsController extends BaseController
{

    /**
     * Action controller function for business.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BusinessActionsRequest $request, $action)
    {
        try {
            $business = BusinessActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('business::business.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('business/business/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('business/business/' . $action))
                ->redirect();
        }
    }
}
