<?php

namespace Eform\Business\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Business\Events\BusinessAction as BusinessActionEvent;
use Eform\Business\Notifications\BusinessAction as BusinessActionNotification;
use Litepie\Actions\Concerns\AsAction;

class BusinessAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the BusinessActionEvent.
     *
     * @param   BusinessActionEvent  $event
     * @return mixed
     */
    public function handle(BusinessActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $business.
     *
     * @param   BusinessActionEvent  $event
     * @return void
     */
    public function create(BusinessActionEvent $event)
    {
        $client = $event->business->client;
        Notification::send($client, new BusinessActionNotification($event));
    }

    /**
     * Handle the BusinessActionEvent as a listener.
     *
     * @param   BusinessActionEvent  $event
     * @return mixed
     */
    public function asListener(BusinessActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   BusinessActionEvent  $event
     * @return bool
     */
    private function isAllowed(BusinessActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
