<?php
namespace Eform\Business\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Eform\Business\Events\BusinessAction as BusinessActionEvent;
use Eform\Business\Models\Business;

class BusinessAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $business;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BusinessActionEvent $business
     */
    public function __construct(BusinessActionEvent $business)
    {
        $this->action = $event->action;
        $this->business = $business;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Business Approved - ' . config('app.name'))
            ->view('business::business.email.action', ['data' => $this->business]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
