<?php

namespace Eform\Business\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Eform\Business\Models\Business;

class BusinessPolicy
{

    use BusinessAction;
    use BusinessExim;

    /**
     * Determine if the given user can view the business.
     *
     * @param Authenticatable $user
     * @param Business $business
     *
     * @return bool
     */
    public function view(Authenticatable $user, Business $business)
    {
        if ($authUser->canDo('business.business.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $business->is_owner;
    }

    /**
     * Determine if the given user can create a business.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('business.business.create');
    }

    /**
     * Determine if the given user can update the given business.
     *
     * @param Authenticatable $user
     * @param Business $business
     *
     * @return bool
     */
    public function update(Authenticatable $user, Business $business)
    {
        if ($user->canDo('business.business.edit') && $user->isAdmin()) {
            return true;
        }

        return $business->is_owner;
    }

    /**
     * Determine if the given user can delete the given business.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Business $business)
    {
        return $business->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
